# Generated by Django 5.2 on 2025-05-10 15:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0002_healthcheck_next_check_time"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthcheck",
            name="processing_started_at",
            field=models.PositiveIntegerField(
                default=0,
                help_text="Unix timestamp when the check started processing",
                verbose_name="Processing Started At",
            ),
        ),
    ]
