# Generated by Django 5.2 on 2025-05-10 14:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthcheck",
            name="next_check_time",
            field=models.PositiveIntegerField(
                default=0,
                help_text="Unix timestamp of the next check",
                verbose_name="Next Check Time",
            ),
        ),
    ]
