# Generated by Django 5.2.1 on 2025-05-17 11:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0004_healthcheck_status"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthcheck",
            name="name",
            field=models.CharField(
                default="",
                help_text="A descriptive name for this health check",
                max_length=255,
                verbose_name="Check Name",
            ),
            preserve_default=False,
        ),
    ]
