# Generated by Django 5.2.1 on 2025-05-18 20:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0005_add_name"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthcheck",
            name="disabled",
            field=models.BooleanField(
                default=False,
                help_text="Disable this health check without deleting it",
                verbose_name="Disabled",
            ),
        ),
    ]
