# Generated by Django 5.2 on 2025-05-10 21:10

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0003_healthcheck_processing_started_at"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthcheck",
            name="status",
            field=models.CharField(
                choices=[("idle", "Idle"), ("processing", "Processing")],
                default="idle",
                max_length=10,
                verbose_name="Status",
            ),
        ),
    ]
